#!/bin/bash

#Created on 2017/08/07

#Install unix odbc and vernox odbc

UNIX_ODBC_INSTALL_PATH="/usr/local/"
UNIX_ODBC_INSTALL_DIR="unixODBC"

UNIX_ODBC_INCLUDE_DIR=${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR}"/include"
UNIX_ODBC_LIB_DIR=${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR}"/lib"
UNIX_ODBC_BIN_DIR=${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR}"/bin"
UNIX_ODBC_CONF_DIR=${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR}"/etc"
UNIX_ODBC_MAN_DIR=${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR}"/share/man"

check_installed()
{
    if [ -e ${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR} ]
    then
        echo "Vernox ODBC had been installed."
        exit
    fi
}

install_unix_odbc()
{
    test -z "${UNIX_ODBC_LIB_DIR}" || /usr/bin/mkdir -p "${UNIX_ODBC_LIB_DIR}"
    test -z "${UNIX_ODBC_CONF_DIR}" || /usr/bin/mkdir -p "${UNIX_ODBC_CONF_DIR}"
    test -z "${UNIX_ODBC_BIN_DIR}" || /usr/bin/mkdir -p "${UNIX_ODBC_BIN_DIR}"
    test -z "${UNIX_ODBC_INCLUDE_DIR}" || /usr/bin/mkdir -p "${UNIX_ODBC_INCLUDE_DIR}"
    test -z "${UNIX_ODBC_MAN_DIR}/man1" || /usr/bin/mkdir -p "${UNIX_ODBC_MAN_DIR}/man1"
    test -z "${UNIX_ODBC_MAN_DIR}/man5" || /usr/bin/mkdir -p "${UNIX_ODBC_MAN_DIR}/man5"
    test -z "${UNIX_ODBC_MAN_DIR}/man7" || /usr/bin/mkdir -p "${UNIX_ODBC_MAN_DIR}/man7"

    cd unixODBC/
    
    /bin/sh libtool --mode=install /usr/bin/install -c libodbcinst.la "${UNIX_ODBC_LIB_DIR}" 1>&2 2>/dev/null
    /bin/sh libtool --mode=install /usr/bin/install -c libodbc.la "${UNIX_ODBC_LIB_DIR}" 1>&2 2>/dev/null
    /bin/sh libtool --mode=install /usr/bin/install -c libodbccr.la "${UNIX_ODBC_LIB_DIR}" 1>&2 2>/dev/null
    /bin/sh libtool --mode=install /usr/bin/install -c isql dltest odbcinst iusql odbc_config slencheck "${UNIX_ODBC_BIN_DIR}" 1>&2 2>/dev/null
    /usr/bin/install -c -m 644 odbcinst.h odbcinstext.h sql.h sqlext.h sqltypes.h sqlucode.h sqlspi.h autotest.h uodbc_stats.h uodbc_extras.h "${UNIX_ODBC_INCLUDE_DIR}" 1>&2 2>/dev/null
    /usr/bin/install -c -m 644 isql.1 odbcinst.1 dltest.1 iusql.1 odbc_config.1 "${UNIX_ODBC_MAN_DIR}/man1" 1>&2 2>/dev/null
    /usr/bin/install -c -m 644 odbc.ini.5 odbcinst.ini.5 "${UNIX_ODBC_MAN_DIR}/man5" 1>&2 2>/dev/null
    /usr/bin/install -c -m 644 unixODBC.7 "${UNIX_ODBC_MAN_DIR}/man7" 1>&2 2>/dev/null
    touch "${UNIX_ODBC_CONF_DIR}"/odbcinst.ini
    touch "${UNIX_ODBC_CONF_DIR}"/odbc.ini
    mkdir -p "${UNIX_ODBC_CONF_DIR}"/ODBCDataSources
    cp unixodbc_conf.h "${UNIX_ODBC_INCLUDE_DIR}"/unixodbc_conf.h
    
    cd ..
}

install_vernox_odbc()
{
    \cp libODBCDriverVernox.so ${UNIX_ODBC_INSTALL_PATH}${UNIX_ODBC_INSTALL_DIR}"/lib"
}

export_enviroment_variables()
{
    if [ -z $(grep ${UNIX_ODBC_INCLUDE_DIR} /etc/profile | grep -w C_INCLUDE_PATH) ]
    then
        echo "C_INCLUDE_PATH=\$C_INCLUDE_PATH:${UNIX_ODBC_INCLUDE_DIR}" >> /etc/profile
        echo "export C_INCLUDE_PATH" >> /etc/profile
    fi
    
    if [ -z $(grep ${UNIX_ODBC_INCLUDE_DIR} /etc/profile | grep -w CPLUS_INCLUDE_PATH) ]
    then
        echo "CPLUS_INCLUDE_PATH=\$CPLUS_INCLUDE_PATH:${UNIX_ODBC_INCLUDE_DIR}" >> /etc/profile
        echo "export CPLUS_INCLUDE_PATH" >> /etc/profile
    fi
	
    if [ -z $(grep ${UNIX_ODBC_INCLUDE_DIR} /etc/profile | grep -w OBJC_INCLUDE_PATH) ]
    then
        echo "OBJC_INCLUDE_PATH=\$OBJC_INCLUDE_PATH:${UNIX_ODBC_INCLUDE_DIR}" >> /etc/profile
        echo "export OBJC_INCLUDE_PATH" >> /etc/profile
	fi
	
    if [ -z  $(grep ${UNIX_ODBC_LIB_DIR} /etc/profile | grep -w LIBRARY_PATH) ]
    then
        echo "LIBRARY_PATH=\$LIBRARY_PATH:${UNIX_ODBC_LIB_DIR}" >> /etc/profile
        echo "export LIBRARY_PATH" >> /etc/profile
    fi
	
    if [ -z $(grep ${UNIX_ODBC_LIB_DIR} /etc/profile | grep -w LD_LIBRARY_PATH) ]
    then
        echo "LD_LIBRARY_PATH=\$LD_LIBRARY_PATH:${UNIX_ODBC_LIB_DIR}" >> /etc/profile
        echo "export LD_LIBRARY_PATH" >> /etc/profile
    fi

    if [ -z $(grep ${UNIX_ODBC_LIB_DIR} /etc/profile | grep -w LD_RUN_PATH) ]
    then
        echo "LD_RUN_PATH=\$LD_RUN_PATH:${UNIX_ODBC_LIB_DIR}" >> /etc/profile
        echo "export LD_RUN_PATH" >> /etc/profile
    fi
    
    if [ -z $(grep ${UNIX_ODBC_BIN_DIR} /etc/profile | grep -w PATH) ]
    then
        echo "PATH=\$PATH:${UNIX_ODBC_BIN_DIR}" >> /etc/profile
        echo "export PATH" >> /etc/profile
    fi
	
    if [ -z  $(grep ${UNIX_ODBC_LIB_DIR} /etc/profile | grep -w LD_PRELOAD) ]
    then
        echo "LD_PRELOAD=\$LD_PRELOAD:${UNIX_ODBC_LIB_DIR}/libodbcinst.so" >> /etc/profile
        echo "export LD_PRELOAD" >> /etc/profile
    fi  

    . /etc/profile
}

info_user()
{
    echo "Vernox ODBC has been install success on your computer."
    echo "Include files have been install in directory: "${UNIX_ODBC_INCLUDE_DIR}
    echo "Lib files have been install in directory: "${UNIX_ODBC_LIB_DIR}
    echo "Configuration files have been install in directory: "${UNIX_ODBC_CONF_DIR}
    echo "Please restart your computer to take effect."
}

check_installed
install_unix_odbc
install_vernox_odbc
export_enviroment_variables
info_user
